.. _sdv.metrics.relational:

sdv.metrics.relational
======================

.. currentmodule:: sdv.metrics.relational

.. autosummary::
   :toctree: api/

    MultiTableMetric
    MultiTableMetric.get_subclasses
    MultiSingleTableMetric
    MultiSingleTableMetric.get_subclasses

Multi Table BayesianNetwork Metrics
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autosummary::
   :toctree: api/

    BNLikelihood
    BNLikelihood.get_subclasses
    BNLikelihood.compute
    BNLogLikelihood
    BNLogLikelihood.get_subclasses
    BNLogLikelihood.compute

Multi Table Statistical Metrics
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autosummary::
   :toctree: api/

    CSTest
    CSTest.get_subclasses
    CSTest.compute
    KSComplement
    KSComplement.get_subclasses
    KSComplement.compute

Multi Table Detection Metrics
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autosummary::
   :toctree: api/

    DetectionMetric
    DetectionMetric.get_subclasses
    LogisticDetection
    LogisticDetection.get_subclasses
    LogisticDetection.compute
    SVCDetection
    SVCDetection.get_subclasses
    SVCDetection.compute
    ParentChildDetectionMetric
    ParentChildDetectionMetric.get_subclasses
    LogisticParentChildDetection
    LogisticParentChildDetection.get_subclasses
    LogisticParentChildDetection.compute
    SVCParentChildDetection
    SVCParentChildDetection.get_subclasses
    SVCParentChildDetection.compute
